@@ -665,11 +665,9 @@ void KWindowInfoX11Test::testDesktopFileName()
 {
     KWindowInfo info(window->winId(), NET::Properties(), NET::WM2DesktopFileName);
     QVERIFY(info.valid());
-    QCOMPARE(info.desktopFileName(), QByteArray());
-
+    QCOMPARE(info.desktopFileName(), "kwindowinfox11test");
     QSignalSpy spy(KX11Extras::self(), &KX11Extras::windowChanged);
     QVERIFY(spy.isValid());
-
     // create a NETWinInfo to set the desktop file name
     NETWinInfo netInfo(QX11Info::connection(), window->winId(), QX11Info::appRootWindow(), NET::Properties(), NET::Properties2());
     netInfo.setDesktopFileName("org.kde.foo");
