@@ -7,15 +7,11 @@
 */
 
 #include "cptr_p.h"
-#include "kwindowsystem_xcb_debug.h"
 #include "kxutils_p.h"
 #include <QBitmap>
+#include <QDebug>
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 #include <private/qtx11extras_p.h>
-#else
-#include <QX11Info>
-#endif
 
 #include <xcb/xcb.h>
 
@@ -90,12 +86,12 @@ QPixmap createPixmapFromHandle(WId pixmap, WId pixmap_mask)
 QPixmap createPixmapFromHandle(xcb_connection_t *c, WId pixmap, WId pixmap_mask)
 {
 #if Q_BYTE_ORDER == Q_BIG_ENDIAN
-    qCDebug(LOG_KKEYSERVER_X11) << "Byte order not supported";
+    qDebug() << "Byte order not supported";
     return QPixmap();
 #endif
     const xcb_setup_t *setup = xcb_get_setup(c);
     if (setup->image_byte_order != XCB_IMAGE_ORDER_LSB_FIRST) {
-        qCDebug(LOG_KKEYSERVER_X11) << "Byte order not supported";
+        qDebug() << "Byte order not supported";
         return QPixmap();
     }
 
